==> flutter_stream_friends-0.1.0.tar.gz: test/flutter_stream_widget_test.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'test_stream_widget.dart';

void main() {
  group('StreamWidget', () {
    testWidgets('takes an optional initial value', (WidgetTester tester) async {
      StreamController<String> streamController =
          new StreamController.broadcast(sync: true);
      var widget = new TestStreamWidget("initial", streamController.stream);

      await tester.pumpWidget(widget);

      expect(widget.currentState, equals("initial"));
    });

    testWidgets('subscribes to the latest state', (WidgetTester tester) async {
      StreamController<String> streamController =
          new StreamController.broadcast(sync: true);
      var widget = new TestStreamWidget("initial", streamController.stream);
      var expected = "test";

      await tester.pumpWidget(widget);

      expect(streamController.hasListener, equals(true));

      streamController.add(expected);
      await tester.pumpWidget(widget);

      expect(widget.currentState, equals(expected));
    });

    testWidgets('unsubscribes on destroy', (WidgetTester tester) async {
      StreamController<String> streamController =
          new StreamController.broadcast(sync: true);
      var widget = new TestStreamWidget("", streamController.stream);

      await tester.pumpWidget(widget);
      expect(streamController.hasListener, equals(true));

      // Create a new Widget tree, which causes the test Widget to be disposed.
      await tester.pumpWidget(new Container());
      expect(streamController.hasListener, equals(false));
    });
  });
}

==> flutter_stream_friends-0.2.0.tar.gz: test/flutter_stream_widget_test.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'test_stream_widget.dart';

void main() {
  group('StreamWidget', () {
    testWidgets('runs buildLoading before any data has been delivered',
        (WidgetTester tester) async {
      StreamController<String> streamController =
          new StreamController.broadcast();
      var widget = new TestStreamWidget("init", streamController.stream);

      await tester.pumpWidget(widget);

      expect(widget.lifeCycle, equals(TestStreamWidget.buildLoadingState));
    });

    testWidgets('subscribes to the latest state', (WidgetTester tester) async {
      StreamController<String> streamController =
          new StreamController.broadcast(sync: true);
      var widget = new TestStreamWidget("initial", streamController.stream);
      var expected = "test";

      await tester.pumpWidget(widget);

      expect(streamController.hasListener, equals(true));

      streamController.add(expected);
      await tester.pumpWidget(widget);

      expect(widget.currentState, equals(expected));
    });

    testWidgets('unsubscribes on destroy', (WidgetTester tester) async {
      StreamController<String> streamController =
          new StreamController.broadcast(sync: true);
      var widget = new TestStreamWidget("", streamController.stream);

      await tester.pumpWidget(widget);
      expect(streamController.hasListener, equals(true));

      // Create a new Widget tree, which causes the test Widget to be disposed.
      await tester.pumpWidget(new Container());
      expect(streamController.hasListener, equals(false));
    });
  });
}
